@@ -1,13 +1,13 @@
 package Perinci::Sub::Complete;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.77'; # VERSION
+our $DATE = '2015-04-09'; # DATE
+our $VERSION = '0.78'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Complete;
 use Complete::Util qw(hashify_answer complete_array_elem combine_answers);
@@ -964,7 +964,7 @@ Perinci::Sub::Complete - Complete command-line argument using Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.77 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-04-02.
+This document describes version 0.78 of Perinci::Sub::Complete (from Perl distribution Perinci-Sub-Complete), released on 2015-04-09.
 
 =head1 SYNOPSIS
 
